==> haskell-skylighting-0.14.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting
version:              0.14.2
visibility:           public
id:                   skylighting-0.14.2-CcN1HhlQgAs4E2Wv456Pwa
key:                  skylighting-0.14.2-CcN1HhlQgAs4E2Wv456Pwa
license:              GPL-2.0-only
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.

category:             Text
abi:                  cd1be74a4bcb4c0340455a9b262e2dd8
exposed:              True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-format-ansi-0.1-4uaP0zsptfP1nGDxo59XkK:Skylighting.Format.ANSI,
    Skylighting.Format.ConTeXt from skylighting-format-context-0.1.0.2-2Wf4PIYXvxXEEvOey0563w:Skylighting.Format.ConTeXt,
    Skylighting.Format.HTML from skylighting-format-blaze-html-0.1.1.3-361ci7YNl5u5CZUQZrj9gE:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-format-latex-0.1-73eQRsZDKbn9DjqIyEhkwS:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx:Skylighting.Types

hidden-modules:
    Skylighting.Syntax.Abc Skylighting.Syntax.Actionscript
    Skylighting.Syntax.Ada Skylighting.Syntax.Agda
    Skylighting.Syntax.Alert Skylighting.Syntax.Apache
    Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
    Skylighting.Syntax.Ats Skylighting.Syntax.Awk
    Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
    Skylighting.Syntax.Boo Skylighting.Syntax.C
    Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
    Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
    Skylighting.Syntax.Coldfusion Skylighting.Syntax.Comments
    Skylighting.Syntax.Commonlisp Skylighting.Syntax.Cpp
    Skylighting.Syntax.Cs Skylighting.Syntax.Css
    Skylighting.Syntax.Curry Skylighting.Syntax.D
    Skylighting.Syntax.Dart Skylighting.Syntax.Debiancontrol
    Skylighting.Syntax.Default Skylighting.Syntax.Diff
    Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
    Skylighting.Syntax.Dosbat Skylighting.Syntax.Dot
    Skylighting.Syntax.Doxygen Skylighting.Syntax.Doxygenlua
    Skylighting.Syntax.Dtd Skylighting.Syntax.Eiffel
    Skylighting.Syntax.Elixir Skylighting.Syntax.Elm
    Skylighting.Syntax.Email Skylighting.Syntax.Erlang
    Skylighting.Syntax.Fasm Skylighting.Syntax.FortranFixed
    Skylighting.Syntax.FortranFree Skylighting.Syntax.Fsharp
    Skylighting.Syntax.Gap Skylighting.Syntax.Gcc
    Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
    Skylighting.Syntax.Go Skylighting.Syntax.Gpr
    Skylighting.Syntax.Graphql Skylighting.Syntax.Groovy
    Skylighting.Syntax.Hamlet Skylighting.Syntax.Haskell
    Skylighting.Syntax.Haxe Skylighting.Syntax.Html
    Skylighting.Syntax.Idris Skylighting.Syntax.Ini
    Skylighting.Syntax.Isocpp Skylighting.Syntax.J
    Skylighting.Syntax.Java Skylighting.Syntax.Javadoc
    Skylighting.Syntax.Javascript Skylighting.Syntax.JavascriptReact
    Skylighting.Syntax.Json Skylighting.Syntax.Jsp
    Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
    Skylighting.Syntax.Latex Skylighting.Syntax.Lex
    Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
    Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
    Skylighting.Syntax.Lua Skylighting.Syntax.M4
    Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
    Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
    Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
    Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
    Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
    Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
    Skylighting.Syntax.Monobasic Skylighting.Syntax.Mustache
    Skylighting.Syntax.Nasm Skylighting.Syntax.Nim
    Skylighting.Syntax.Nix Skylighting.Syntax.Noweb
    Skylighting.Syntax.Objectivec Skylighting.Syntax.Objectivecpp
    Skylighting.Syntax.Ocaml Skylighting.Syntax.Octave
    Skylighting.Syntax.Opencl Skylighting.Syntax.Orgmode
    Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
    Skylighting.Syntax.Php Skylighting.Syntax.Pike
    Skylighting.Syntax.Postscript Skylighting.Syntax.Povray
    Skylighting.Syntax.Powershell Skylighting.Syntax.Prolog
    Skylighting.Syntax.Protobuf Skylighting.Syntax.Pure
    Skylighting.Syntax.Purebasic Skylighting.Syntax.Purescript
    Skylighting.Syntax.Python Skylighting.Syntax.Qml
    Skylighting.Syntax.R Skylighting.Syntax.Raku
    Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
    Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
    Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
    Skylighting.Syntax.Rust Skylighting.Syntax.Sass
    Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
    Skylighting.Syntax.Sci Skylighting.Syntax.Scss
    Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
    Skylighting.Syntax.Sml Skylighting.Syntax.SpdxComments
    Skylighting.Syntax.Sql Skylighting.Syntax.SqlMysql
    Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Stan
    Skylighting.Syntax.Stata Skylighting.Syntax.Swift
    Skylighting.Syntax.Systemverilog Skylighting.Syntax.Tcl
    Skylighting.Syntax.Tcsh Skylighting.Syntax.Terraform
    Skylighting.Syntax.Texinfo Skylighting.Syntax.Toml
    Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
    Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
    Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
    Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
    Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-0.14.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-0.14.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting
hs-libraries:         HSskylighting-0.14.2-CcN1HhlQgAs4E2Wv456Pwa
depends:
    base-4.17.2.1 binary-0.8.9.1 containers-0.6.7
    skylighting-core-0.14.2-J43F2XC5BhlLWiTYO5jesx
    skylighting-format-ansi-0.1-4uaP0zsptfP1nGDxo59XkK
    skylighting-format-blaze-html-0.1.1.3-361ci7YNl5u5CZUQZrj9gE
    skylighting-format-context-0.1.0.2-2Wf4PIYXvxXEEvOey0563w
    skylighting-format-latex-0.1-73eQRsZDKbn9DjqIyEhkwS

haddock-interfaces:   /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html:         /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.14.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting
version:              0.14.2
visibility:           public
id:                   skylighting-0.14.2-7V5AIbRsUBXBNaAb7gLlfR
key:                  skylighting-0.14.2-7V5AIbRsUBXBNaAb7gLlfR
license:              GPL-2.0-only
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.

category:             Text
abi:                  cf49ff005e14cf4a4bc1eb1a183e1e8c
exposed:              True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-format-ansi-0.1-A1IX6pRnogW4n8diauSsew:Skylighting.Format.ANSI,
    Skylighting.Format.ConTeXt from skylighting-format-context-0.1.0.2-KQGww8rovSBBtkjJOSnUiO:Skylighting.Format.ConTeXt,
    Skylighting.Format.HTML from skylighting-format-blaze-html-0.1.1.3-9ETGpDoaVso71vbHNAgSyX:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-format-latex-0.1-2U7vzCf08JeJbqcnuxi0BP:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO:Skylighting.Types

hidden-modules:
    Skylighting.Syntax.Abc Skylighting.Syntax.Actionscript
    Skylighting.Syntax.Ada Skylighting.Syntax.Agda
    Skylighting.Syntax.Alert Skylighting.Syntax.Apache
    Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
    Skylighting.Syntax.Ats Skylighting.Syntax.Awk
    Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
    Skylighting.Syntax.Boo Skylighting.Syntax.C
    Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
    Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
    Skylighting.Syntax.Coldfusion Skylighting.Syntax.Comments
    Skylighting.Syntax.Commonlisp Skylighting.Syntax.Cpp
    Skylighting.Syntax.Cs Skylighting.Syntax.Css
    Skylighting.Syntax.Curry Skylighting.Syntax.D
    Skylighting.Syntax.Dart Skylighting.Syntax.Debiancontrol
    Skylighting.Syntax.Default Skylighting.Syntax.Diff
    Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
    Skylighting.Syntax.Dosbat Skylighting.Syntax.Dot
    Skylighting.Syntax.Doxygen Skylighting.Syntax.Doxygenlua
    Skylighting.Syntax.Dtd Skylighting.Syntax.Eiffel
    Skylighting.Syntax.Elixir Skylighting.Syntax.Elm
    Skylighting.Syntax.Email Skylighting.Syntax.Erlang
    Skylighting.Syntax.Fasm Skylighting.Syntax.FortranFixed
    Skylighting.Syntax.FortranFree Skylighting.Syntax.Fsharp
    Skylighting.Syntax.Gap Skylighting.Syntax.Gcc
    Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
    Skylighting.Syntax.Go Skylighting.Syntax.Gpr
    Skylighting.Syntax.Graphql Skylighting.Syntax.Groovy
    Skylighting.Syntax.Hamlet Skylighting.Syntax.Haskell
    Skylighting.Syntax.Haxe Skylighting.Syntax.Html
    Skylighting.Syntax.Idris Skylighting.Syntax.Ini
    Skylighting.Syntax.Isocpp Skylighting.Syntax.J
    Skylighting.Syntax.Java Skylighting.Syntax.Javadoc
    Skylighting.Syntax.Javascript Skylighting.Syntax.JavascriptReact
    Skylighting.Syntax.Json Skylighting.Syntax.Jsp
    Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
    Skylighting.Syntax.Latex Skylighting.Syntax.Lex
    Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
    Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
    Skylighting.Syntax.Lua Skylighting.Syntax.M4
    Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
    Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
    Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
    Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
    Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
    Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
    Skylighting.Syntax.Monobasic Skylighting.Syntax.Mustache
    Skylighting.Syntax.Nasm Skylighting.Syntax.Nim
    Skylighting.Syntax.Nix Skylighting.Syntax.Noweb
    Skylighting.Syntax.Objectivec Skylighting.Syntax.Objectivecpp
    Skylighting.Syntax.Ocaml Skylighting.Syntax.Octave
    Skylighting.Syntax.Opencl Skylighting.Syntax.Orgmode
    Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
    Skylighting.Syntax.Php Skylighting.Syntax.Pike
    Skylighting.Syntax.Postscript Skylighting.Syntax.Povray
    Skylighting.Syntax.Powershell Skylighting.Syntax.Prolog
    Skylighting.Syntax.Protobuf Skylighting.Syntax.Pure
    Skylighting.Syntax.Purebasic Skylighting.Syntax.Purescript
    Skylighting.Syntax.Python Skylighting.Syntax.Qml
    Skylighting.Syntax.R Skylighting.Syntax.Raku
    Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
    Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
    Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
    Skylighting.Syntax.Rust Skylighting.Syntax.Sass
    Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
    Skylighting.Syntax.Sci Skylighting.Syntax.Scss
    Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
    Skylighting.Syntax.Sml Skylighting.Syntax.SpdxComments
    Skylighting.Syntax.Sql Skylighting.Syntax.SqlMysql
    Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Stan
    Skylighting.Syntax.Stata Skylighting.Syntax.Swift
    Skylighting.Syntax.Systemverilog Skylighting.Syntax.Tcl
    Skylighting.Syntax.Tcsh Skylighting.Syntax.Terraform
    Skylighting.Syntax.Texinfo Skylighting.Syntax.Toml
    Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
    Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
    Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
    Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
    Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-0.14.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-0.14.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting
hs-libraries:         HSskylighting-0.14.2-7V5AIbRsUBXBNaAb7gLlfR
depends:
    base-4.17.2.1 binary-0.8.9.1 containers-0.6.7
    skylighting-core-0.14.2-7og0O7cZBFa3AFgOI6M5IO
    skylighting-format-ansi-0.1-A1IX6pRnogW4n8diauSsew
    skylighting-format-blaze-html-0.1.1.3-9ETGpDoaVso71vbHNAgSyX
    skylighting-format-context-0.1.0.2-KQGww8rovSBBtkjJOSnUiO
    skylighting-format-latex-0.1-2U7vzCf08JeJbqcnuxi0BP

haddock-interfaces:   /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html:         /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
